# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify CentOS Linux and Scientific Linux as rhel
%if "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "sl" || "%{__distinit}" == "sls"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

# perl_vendorlib/perl_vendorarch not defined by default prior to F-2
%{!?perl_vendorlib: %global perl_vendorlib %(eval "`perl -V:installvendorlib`"; echo $installvendorlib)}

Name:		perl-PPI
Version:	1.215
Release:	3.%{__distinit}%{__distvers}
Summary:	Parse, Analyze and Manipulate Perl
Group:		Development/Libraries
License:	GPL+ or Artistic
URL:		http://search.cpan.org/dist/PPI/
Source0:	http://search.cpan.org/CPAN/authors/id/A/AD/ADAMK/PPI-%{version}.tar.gz
Patch0:		PPI-1.213-Test::More-downgrade.patch
Patch1:		PPI-1.213-Perl::MinimumVersion-downgrade.patch
Patch2:		PPI-1.215-utf8.patch
BuildRoot:	%{_tmppath}/%{name}-%{version}-%{release}-root-%(id -nu)
BuildArch:	noarch
BuildRequires:	perl(Class::Inspector) >= 1.22
BuildRequires:	perl(Clone) >= 0.25
BuildRequires:	perl(File::Remove) >= 0.39
BuildRequires:	perl(IO::String) >= 1.07
BuildRequires:	perl(List::MoreUtils) >= 0.16
BuildRequires:	perl(List::Util)
BuildRequires:	perl(Params::Util) >= 1.00
BuildRequires:	perl(Storable)
BuildRequires:	perl(Task::Weaken)
BuildRequires:	perl(Test::More)
BuildRequires:	perl(Test::NoWarnings)
BuildRequires:	perl(Test::Object) >= 0.07
BuildRequires:	perl(Test::SubCalls) >= 1.07
# Circular dependencies in release tests, so don't do them when bootstrapping:
# Perl::MinimumVersion -> PPI
%if 0%{!?perl_bootstrap:1}
BuildRequires:	perl(File::Find::Rule) >= 0.32
BuildRequires:	perl(File::Find::Rule::Perl) >= 1.09
BuildRequires:	perl(Perl::MinimumVersion) >= 1.20
BuildRequires:	perl(Test::ClassAPI) >= 1.03
BuildRequires:	perl(Test::CPAN::Meta)
BuildRequires:	perl(Test::MinimumVersion) >= 0.101080
BuildRequires:	perl(Test::Pod) >= 1.00
%endif
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))

%global test_more_version_ok %(perl -MTest::More -e 'eval "use Test::More 0.86"; print $@ ? 0 : 1;' 2>/dev/null || echo 0)
%global pmv_version_ok %(perl -MPerl::MinimumVersion -e 'eval "use Perl::MinimumVersion 1.25"; print $@ ? 0 : 1;' 2>/dev/null || echo 0)

# Filter out redundant unversioned provides (rpm 4.9 onwards)
%global __provides_exclude ^perl\\(PPI::.+\\)$

%description
Parse, analyze and manipulate Perl (without perl).

%prep
%setup -q -n PPI-%{version}

# Downgrade Test::More version requirement if we can't satisfy it
%if ! %{test_more_version_ok}
%patch0 -p1
%endif

# Downgrade Perl::MinimumVersion requirement if we can't satisfy it
%if ! %{pmv_version_ok}
%patch1 -p1
%endif

# Recode documentation as UTF-8
%patch2

# Filter out redundant unversioned provides (prior to rpm 4.9)
%global provfilt /bin/sh -c "%{__perl_provides} | grep -Evx 'perl[(]PPI::.+[)]'"
%define __perl_provides %{provfilt}

%build
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%install
rm -rf %{buildroot}
make pure_install PERL_INSTALL_ROOT=%{buildroot}
find %{buildroot} -type f -name .packlist -exec rm -f {} \;
%{_fixperms} %{buildroot}

%check
make test
%if 0%{!?perl_bootstrap:1}
make test TEST_FILES="xt/*.t" RELEASE_TESTING=1
%endif

%clean
rm -rf %{buildroot}

%files
%defattr(-,root,root,-)
%doc Changes LICENSE README inline2test.conf inline2test.tpl
%{perl_vendorlib}/PPI/
%{perl_vendorlib}/PPI.pm
%{_mandir}/man3/PPI*.3pm*

%changelog
* Fri Mar  2 2012 Paul Howarth <paul@city-fan.org> - 1.215-3
- Bump Params::Util version requirement to 1.00 as per upstream
- Don't need to remove empty directories from buildroot
- Don't need to fix permissions of files from tarball
- Use a patch rather than scripted iconv to fix character encoding

* Wed Jun 29 2011 Paul Howarth <paul@city-fan.org> - 1.215-2
- Rebuild for perl 5.14.1 in Rawhide
- Add support for perl_bootstrap macro
- Explicitly BR: Class::Inspector and Test::More
- Nobody else likes macros for commands
- Fix dist tag for CentOS 6 and Scientific Linux

* Sat Feb 26 2011 Paul Howarth <paul@city-fan.org> - 1.215-1
- Updated to 1.215:
  - index_locations on an empty document no longer warns
  - Corrected a bug in line-spanning attribute support
  - Regression test for line-spanning attribute support
  - return { foo => 1 } should parse curlys as hash constructor, not block
    (CPAN RT#61305)
  - Fixed bug with map and regexp confusing PPI (CPAN RT#63943)
  - Updated copyright year to 2011 (ADAMK)
  - Fix bless {} probably contains a hash constructor (CPAN RT#64247)
  - Backed out glob fix
  - Fix cast can trump braces in PPI::Token::Symbol->symbol (CPAN RT#65199)

* Wed Jul  7 2010 Paul Howarth <paul@city-fan.org> - 1.213-1
- Updated to 1.213:
  - Updated to Module::Install 1.00
  - Updated module dependencies in xt author tests
  - Fixed extremely broken PPI::Token::Pod::merge and added test case
- Update Test::More downgrade patch
- Release tests moved to xt/
- BR: perl(File::Find::Rule) >= 0.32, perl(File::Find::Rule::Perl) >= 1.09,
  perl(Perl::MinimumVersion) >= 1.20 and perl(Test::MinimumVersion) >= 0.101080
  for release tests
- Downgrade Perl::MinimumVersion requirement to 1.20 if we don't have 1.25 or
  later, to support builds on older releases

* Wed Jun 23 2010 Paul Howarth <paul@city-fan.org> - 1.212-2
- Rebuild for perl 5.12.1 in Rawhide

* Sat May  8 2010 Paul Howarth <paul@city-fan.org> - 1.212-1
- Updated to 1.212:
  - Fixed bug in ForLoop back-compatibility warning (CPAN RT#48819)
  - Added support for $ENV{X_TOKENIZER} --> $PPI::Lexer::X_TOKENIZER
  - Upgraded to Module::Install 0.93
  - Added support for $PPI::Lexer::X_TOKENIZER, for alternate tokenizers
  - Added an extra test case to validate we handle byte order marks properly
  - Moved author tests from t to xt
  - Fixed CPAN RT#26082: scalar { %%x } is misparsed
  - Fixed CPAN RT#26591: VMS patch for PPI 1.118
  - Fixed CPAN RT#44862: PPI cannot parse "package Foo::100;" correctly
  - Fixed CPAN RT#54208: PPI::Token::Quote::Literal::literal missing
- Fix dist tag to work with RHEL6 Beta

* Tue Feb 16 2010 Paul Howarth <paul@city-fan.org> - 1.210-1
- Update to 1.210 (packaging fixes)
- Use RELEASE_TESTING rather than AUTOMATED_TESTING for better test coverage

* Sun Feb  7 2010 Paul Howarth <paul@city-fan.org> - 1.209-1
- Update to 1.209 (small optimization release)

* Wed Feb  3 2010 Paul Howarth <paul@city-fan.org> - 1.208-2
- Use %%{_fixperms} macro instead of our own %%{__chmod} incantation

* Fri Jan 15 2010 Paul Howarth <paul@city-fan.org> - 1.208-1
- Update to 1.208
  - Don't assign '' to $^W, it generates a warning on Gentoo
  - Added missing PPI::Token::Regexp fix to Changes file
  - Updating Copyright to the new year
  - Fixed #50309: literal() wrong result on "qw (a b c)"
  - PPI::Dumper no longer causes Elements to flush location data
  - PPI::Dumperno longer disables location information for non-Documents
  - +{ package => 1 } doesn't create a PPI::Statement::Package
  - Extra methods in PPI::Token::Regexp and PPI::Token::QuoteLike::Regexp
- Dist tag for Rawhide no longer needs special-casing

* Mon Aug 10 2009 Paul Howarth <paul@city-fan.org> - 1.206-1
- Update to 1.206 (optimisation release - 1-2% speed up)
- Add buildreq perl(Task::Weaken) for improved test coverage

* Mon Aug  3 2009 Paul Howarth <paul@city-fan.org> - 1.205-1
- Update to 1.205 (many updates - see Changes for details)
- Drop charsets.t patch, now upstream
- Drop Lexer patch for perl 5.8.0, problem fixed upstream
- Add provides filter to remove redundant unversioned provides
- Apply patch to downgrade Test::More requirement if we can't satisfy it

* Fri Jun  5 2009 Paul Howarth <paul@city-fan.org> - 1.203-1
- Update to 1.203
- Add workaround for "Can't use an undefined value as an ARRAY reference"
  error in Lexer.pm on RHL9, RHEL3
- Fix charsets.t to not gobble all available memory on FC4, FC4, RHEL4
  (RT#35917), and add associated buildreq perl(Test::NoWarnings)
- Re-add perl(Test::ClassAPI) buildreq
- Enable AUTOMATED_TESTING and add associated buildreq perl(Test::CPAN::Meta)
- Bump version requirements:
  perl(Clone) >= 0.25
  perl(File::Remove) >= 0.39
  perl(List::MoreUtils) >= 0.16
  perl(Params::Util) >= 0.17 (latest version possible on RHEL3)
  perl(Test::ClassAPI) >= 1.03
  perl(Test::Object) >= 0.07
  perl(Test::SubCalls) >= 1.07
- Update to SLES-compatible dist tag macros

* Mon Sep  1 2008 Paul Howarth <paul@city-fan.org> - 1.201-4
- Import from Fedora
- Fix character encoding of Changes file
- Drop version requirement of perl(List::Util) and perl(Storable) for builds
  on older distributions
- Drop perl(Test::ClassAPI) buildreq for now

* Wed Feb 27 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 1.201-3
- Rebuild for perl 5.10 (again)

* Sun Jan 13 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 1.201-2
- Rebuild for new perl

* Wed Dec 19 2007 Tom "spot" Callaway <tcallawa@redhat.com> - 1.201-1
- Bump to 1.201

* Sat Sep 23 2006 Jose Pedro Oliveira <jpo at di.uminho.pt> - 1.118-1
- Update to 1.118.

* Wed Sep  6 2006 Jose Pedro Oliveira <jpo at di.uminho.pt> - 1.117-1
- Update to 1.117.

* Sun Jun  4 2006 Jose Pedro Oliveira <jpo at di.uminho.pt> - 1.115-2
- Removed the perl(IO::Scalar) build requirement.

* Sun Jun  4 2006 Jose Pedro Oliveira <jpo at di.uminho.pt> - 1.115-1
- Update to 1.115.

* Wed May 10 2006 Jose Pedro Oliveira <jpo at di.uminho.pt> - 1.113-1
- Update to 1.113.

* Tue Apr 25 2006 Jose Pedro Oliveira <jpo at di.uminho.pt> - 1.112-1
- Update to 1.112.

* Sat Apr 22 2006 Jose Pedro Oliveira <jpo at di.uminho.pt> - 1.111-1
- First build.
